# Changes

## 2022.9.25

* Initial implementation for sinmilarity assessment including command line interface
* Added usage documentation and amended third-party docs

## 2022.9.24

* Initial release on PyPI
